TxpoolReadRequest

Enum TxpoolReadRequest 

pub enum TxpoolReadRequest {
Show 13 variants TxBlob(TransactionHash), TxVerificationData(TransactionHash), FilterKnownTxBlobHashes(HashSet<TransactionBlobHash>), TxsForBlock(Vec<TransactionHash>), Backlog, Size { include_sensitive_txs: bool, }, PoolInfo { include_sensitive_txs: bool, max_tx_count: usize, start_time: Option<NonZero<usize>>, }, TxsByHash { tx_hashes: Vec<[u8; 32]>, include_sensitive_txs: bool, }, KeyImagesSpent { key_images: HashSet<[u8; 32]>, include_sensitive_txs: bool, }, KeyImagesSpentVec { key_images: Vec<[u8; 32]>, include_sensitive_txs: bool, }, Pool { include_sensitive_txs: bool, }, PoolStats { include_sensitive_txs: bool, }, AllHashes { include_sensitive_txs: bool, },
}
The transaction pool [tower::Service] read request type.

include_sensitive_txs

This field exists in many requests. If this is true, the request will include private (local) transactions in the response.

Variants



TxBlob(TransactionHash)

Get the blob (raw bytes) of a transaction with the given hash.



TxVerificationData(TransactionHash)

Get the [TransactionVerificationData] of a transaction in the tx pool.



FilterKnownTxBlobHashes(HashSet<TransactionBlobHash>)

Filter (remove) all known transactions from the set.

The hash is not the transaction hash, it is the hash of the serialized tx-blob.



TxsForBlock(Vec<TransactionHash>)

Get some transactions for an incoming block.



Backlog

Get information on all transactions in the pool.



Size

Get the number of transactions in the pool.

Fields

include_sensitive_txs: bool


PoolInfo

Get general information on the txpool.

Fields

include_sensitive_txs: bool
max_tx_count: usize

The maximum amount of transactions to retrieve.

start_time: Option<NonZero<usize>>

Fetch transactions that start from this time.

None means all transactions.



TxsByHash

Get transactions by their hashes.

Fields

tx_hashes: Vec<[u8; 32]>
include_sensitive_txs: bool


KeyImagesSpent

Check if any individual key images of a set exist in the txpool.

Fields

key_images: HashSet<[u8; 32]>
include_sensitive_txs: bool


KeyImagesSpentVec

Same as TxpoolReadRequest::KeyImagesSpent but with a Vec.

The response will be in the same order as the request.

Fields

key_images: Vec<[u8; 32]>
include_sensitive_txs: bool


Pool

Get txpool info.

Fields

include_sensitive_txs: bool


PoolStats

Get txpool stats.

Fields

include_sensitive_txs: bool


AllHashes

Get the hashes of all transaction in the pool.

Fields

include_sensitive_txs: bool