TxpoolReadResponse

Enum TxpoolReadResponse 

pub enum TxpoolReadResponse {
Show 13 variants TxBlob { tx_blob: Vec<u8>, state_stem: bool, }, TxVerificationData(TransactionVerificationData), FilterKnownTxBlobHashes { unknown_blob_hashes: HashSet<TransactionBlobHash>, stem_pool_hashes: Vec<TransactionHash>, }, TxsForBlock { txs: HashMap<[u8; 32], TransactionVerificationData>, missing: Vec<usize>, }, Backlog(Vec<TxEntry>), Size(usize), PoolInfo(PoolInfo), TxsByHash(Vec<TxInPool>), KeyImagesSpent(bool), KeyImagesSpentVec(Vec<bool>), Pool { txs: Vec<TxInfo>, spent_key_images: Vec<SpentKeyImageInfo>, }, PoolStats(TxpoolStats), AllHashes(Vec<[u8; 32]>),
}
The transaction pool [tower::Service] read response type.

Variants



TxBlob

The response for TxpoolReadRequest::TxBlob.

Fields

tx_blob: Vec<u8>
state_stem: bool


TxVerificationData(TransactionVerificationData)



FilterKnownTxBlobHashes

Fields

unknown_blob_hashes: HashSet<TransactionBlobHash>

The blob hashes that are unknown.

stem_pool_hashes: Vec<TransactionHash>

The tx hashes of the blob hashes that were known but were in the stem pool.



TxsForBlock

Fields

txs: HashMap<[u8; 32], TransactionVerificationData>

The txs we had in the txpool.

missing: Vec<usize>

The indexes of the missing txs.



Backlog(Vec<TxEntry>)

Response to TxpoolReadRequest::Backlog.

The inner Vec contains information on all the transactions currently in the pool.



Size(usize)

Response to TxpoolReadRequest::Size.

The inner value is the amount of transactions currently in the pool.



PoolInfo(PoolInfo)



TxsByHash(Vec<TxInPool>)



KeyImagesSpent(bool)



KeyImagesSpentVec(Vec<bool>)

Response to TxpoolReadRequest::KeyImagesSpentVec.

Inner value is a Vec the same length as the input.

The index of each entry corresponds with the request. true means that the key image was spent.



Pool

Fields

txs: Vec<TxInfo>
spent_key_images: Vec<SpentKeyImageInfo>


PoolStats(TxpoolStats)



AllHashes(Vec<[u8; 32]>)