TxpoolWriteRequest

Enum TxpoolWriteRequest 

pub enum TxpoolWriteRequest {
    AddTransaction {
        tx: Box<TransactionVerificationData>,
        state_stem: bool,
    },
    RemoveTransaction(TransactionHash),
    Promote(TransactionHash),
    NewBlock {
        spent_key_images: Vec<KeyImage>,
    },
}
The transaction pool [tower::Service] write request type.

Variants



AddTransaction

Add a transaction to the pool.

Returns TxpoolWriteResponse::AddTransaction.

Fields

tx: Box<TransactionVerificationData>

The tx to add.

state_stem: bool

A bool denoting the routing state of this tx.

true if this tx is in the stem state.



RemoveTransaction(TransactionHash)

Remove a transaction with the given hash from the pool.



Promote(TransactionHash)

Promote a transaction from the stem pool to the fluff pool. If the tx is already in the fluff pool this does nothing.



NewBlock

Tell the tx-pool about a new block.

Fields

spent_key_images: Vec<KeyImage>

The spent key images in the new block.