pub enum TxpoolWriteResponse {
Ok,
NewBlock(Vec<TransactionHash>),
AddTransaction(Option<TransactionHash>),
}Expand description
The transaction pool [tower::Service] write response type.
Variants
Ok
NewBlock(Vec<TransactionHash>)
Response to TxpoolWriteRequest::NewBlock.
The inner values are the transactions removed from the pool.
AddTransaction(Option<TransactionHash>)
Response to TxpoolWriteRequest::AddTransaction.
If the inner value is Some the tx was not added to the pool as it double spends a tx with the given hash.