pub enum TxpoolWriteRequest {
AddTransaction {
tx: Box<TransactionVerificationData>,
state_stem: bool,
},
RemoveTransaction(TransactionHash),
Promote(TransactionHash),
NewBlock {
spent_key_images: Vec<KeyImage>,
},
}Expand description
The transaction pool [tower::Service] write request type.
Variants
AddTransaction
Add a transaction to the pool.
Returns TxpoolWriteResponse::AddTransaction.
Fields
RemoveTransaction(TransactionHash)
Remove a transaction with the given hash from the pool.
Promote(TransactionHash)
Promote a transaction from the stem pool to the fluff pool. If the tx is already in the fluff pool this does nothing.
NewBlock
Tell the tx-pool about a new block.